## 自己手写的 logger
>不喜勿喷
>
[![LICENSE](https://img.shields.io/badge/license-Anti%20996-blue.svg)](https://github.com/996icu/996.ICU/blob/master/LICENSE)
[![996.icu](https://img.shields.io/badge/link-996.icu-red.svg)](https://996.icu)

## Getting Started:
```bash
pip install msdnicrosoft_logger
```

## Example:
```python
import msdnicrosoft_logger
logger = msdnicrosoft_logger.Log(Shell=True,LogFile=True,FileName="%Y-%m-%d_%H-%M.log")
# ... Enter your code there
```

